<?php

namespace Agency\Contact\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Agency\Contact\Http\Requests\ContactCategoryRequest;
use Agency\Contact\Interfaces\ContactCategoryRepositoryInterface;
use Agency\Contact\Models\ContactCategory;
use Agency\Contact\Forms\ContactCategory as Form;

/**
 * APIController  class for contact_category.
 */
class ContactCategoryAPIController extends BaseController
{

    /**
     * Initialize contact_category resource controller.
     *
     * @param type ContactCategoryRepositoryInterface $contact_category
     *
     * @return null
     */
    public function __construct(ContactCategoryRepositoryInterface $contact_category)
    {
        parent::__construct();
        $this->repository = $contact_category;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Agency\Contact\Repositories\Criteria\ContactCategoryResourceCriteria::class);
    }

    /**
     * Display a list of contact_category.
     *
     * @return Response
     */
    public function index(ContactCategoryRequest $request)
    {
        return $this->repository
            ->setPresenter(\Agency\Contact\Repositories\Presenter\ContactCategoryPresenter::class)
            ->paginate();
    }

    /**
     * Display contact_category.
     *
     * @param Request $request
     * @param Model   $contact_category
     *
     * @return Response
     */
    public function show(ContactCategoryRequest $request, ContactCategory $contact_category)
    {
        return $contact_category->setPresenter(\Agency\Contact\Repositories\Presenter\ContactCategoryListPresenter::class);
        ;
    }

    /**
     * Create new contact_category.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ContactCategoryRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('contact::contact_category.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('contact/contact_category/' . $contact_category->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('contact/contact_category');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the contact_category.
     *
     * @param Request $request
     * @param Model   $contact_category
     *
     * @return Response
     */
    public function update(ContactCategoryRequest $request, ContactCategory $contact_category)
    {
        try {
            $data = $request->all();

            $contact_category->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('contact::contact_category.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('contact/contact_category/' . $contact_category->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('contact/contact_category/' . $contact_category->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the contact_category.
     *
     * @param Model   $contact_category
     *
     * @return Response
     */
    public function destroy(ContactCategoryRequest $request, ContactCategory $contact_category)
    {
        try {
            $contact_category->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('contact::contact_category.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('contact/contact_category/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('contact/contact_category/' . $contact_category->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
