<?php

namespace Agency\Contact\Policies;

use Litepie\User\Contracts\UserPolicy;
use Agency\Contact\Models\ContactCategory;

class ContactCategoryPolicy
{

    /**
     * Determine if the given user can view the contact_category.
     *
     * @param UserPolicy $user
     * @param ContactCategory $contact_category
     *
     * @return bool
     */
    public function view(UserPolicy $user, ContactCategory $contact_category)
    {
        if ($user->canDo('contact.contact_category.view') && $user->isAdmin()) {
            return true;
        }

        return $contact_category->user_id == user_id() && $contact_category->user_type == user_type();
    }

    /**
     * Determine if the given user can create a contact_category.
     *
     * @param UserPolicy $user
     * @param ContactCategory $contact_category
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('contact.contact_category.create');
    }

    /**
     * Determine if the given user can update the given contact_category.
     *
     * @param UserPolicy $user
     * @param ContactCategory $contact_category
     *
     * @return bool
     */
    public function update(UserPolicy $user, ContactCategory $contact_category)
    {
        if ($user->canDo('contact.contact_category.edit') && $user->isAdmin()) {
            return true;
        }

        return $contact_category->user_id == user_id() && $contact_category->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given contact_category.
     *
     * @param UserPolicy $user
     * @param ContactCategory $contact_category
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ContactCategory $contact_category)
    {
        return $contact_category->user_id == user_id() && $contact_category->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given contact_category.
     *
     * @param UserPolicy $user
     * @param ContactCategory $contact_category
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ContactCategory $contact_category)
    {
        if ($user->canDo('contact.contact_category.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given contact_category.
     *
     * @param UserPolicy $user
     * @param ContactCategory $contact_category
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ContactCategory $contact_category)
    {
        if ($user->canDo('contact.contact_category.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
