<?php

namespace Agency\Contact\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Agency\Contact\Models\Contact;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Agency\Contact\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/contact/contact_category/*')) {
            Route::bind('contact_category', function ($contact_category) {
                $contact_categoryrepo = $this->app->make('Agency\Contact\Interfaces\ContactCategoryRepositoryInterface');
                return $contact_categoryrepo->findorNew($contact_category);
            });
        }

        if (Request::is('*/contact/contact/*')) {
            Route::bind('contact', function ($contact) {
                $contactrepo = $this->app->make('Agency\Contact\Interfaces\ContactRepositoryInterface');
                return $contactrepo->findorNew($contact);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
